/*
 * Copyright (c) 2000-2014 Antonio De Lorenzo <antonio.delorenzo@develit.eu>
 *
 * Redistribution and use in source and binary forms, with or without modifica-
 * tion, are permitted provided that the following conditions are met:
 *
 *   1.  Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *
 *   2.  Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MER-
 * CHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPE-
 * CIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTH-
 * ERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * the GNU General Public License ("GPL") version 2 or any later version,
 * in which case the provisions of the GPL are applicable instead of
 * the above. If you wish to allow the use of your version of this file
 * only under the terms of the GPL and not to allow others to use your
 * version of this file under the BSD license, indicate your decision
 * by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL. If you do not delete the
 * provisions above, a recipient may use your version of this file under
 * either the BSD or the GPL.
 */
 
#include "Utility.h"
#include "MessageLogger.h"

#include <stdio.h>
#include <iostream>
#include <sstream>

// MessageLoggerSingleton
MessageLogger* MessageLoggerSingleton::m_messageLogger;

MessageLoggerSingleton::MessageLoggerSingleton(MessageLogger& messageLogger){
	if(NULL==m_messageLogger)
		m_messageLogger=&messageLogger;
}

MessageLoggerSingleton::~MessageLoggerSingleton(){
}
	
MessageLogger& MessageLoggerSingleton::GetLogger(){
	if(NULL==m_messageLogger){
		std::cerr <<"ERROR [GetLogger]: Logger not registered" <<std::endl;
		throw(0);
	}
	
	return *m_messageLogger;
}

// IntToString
char* IntToString(const int value, char* stringBuffer){
	sprintf(stringBuffer, "%i", value);
	return stringBuffer;
}

// StringToInt
int StringToInt(const char* string){
	int i(0);
	sscanf(string, "%i", &i);
	
	return i;
}

#ifdef USE_XML_AND_FLTK

// LoadXmlAttribute
const char* LoadXmlAttribute(const tinyxml2::XMLElement& element, const char* field, const char* errorMessageHeader){
	const char* result(element.Attribute(field));
	if(NULL==result){
		if(NULL!=errorMessageHeader){
			std::stringstream message;
			message <<errorMessageHeader <<": " <<field <<" missing.";
			throw(LOGGER(0, LM_ERROR, "LoadXmlAttribute", message.str()));
		} else
			throw(0);
	}
	
	return result;
}

void Fl_MaximizeLabelFont(Fl_Widget& widget){
	for(int iFontHeightFactor(2); iFontHeightFactor<8; ++iFontHeightFactor){
		widget.labelsize(widget.h()/iFontHeightFactor);
		int lW(0);
		int lH(0);
		widget.measure_label(lW, lH);
		if(lW<=widget.w()){
			break;
		}
	}
}

Fl_Color Fl_GetSelectedColor(Fl_Color color){
	for(int i(0); i<2; color=fl_lighter(color), ++i);
	return color;
}

int GetScreenWidth(){
	int dummy;
	int width(0);	
	Fl::screen_xywh(dummy, dummy, width, dummy);
	
	return width;
}

#endif
