/*
 * Copyright (c) 2000-2014 Antonio De Lorenzo <antonio.delorenzo@develit.eu>
 *
 * Redistribution and use in source and binary forms, with or without modifica-
 * tion, are permitted provided that the following conditions are met:
 *
 *   1.  Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *
 *   2.  Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MER-
 * CHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
 * EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPE-
 * CIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTH-
 * ERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * the GNU General Public License ("GPL") version 2 or any later version,
 * in which case the provisions of the GPL are applicable instead of
 * the above. If you wish to allow the use of your version of this file
 * only under the terms of the GPL and not to allow others to use your
 * version of this file under the BSD license, indicate your decision
 * by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL. If you do not delete the
 * provisions above, a recipient may use your version of this file under
 * either the BSD or the GPL.
 */

#ifndef _UTILITY_H_FILE_
#define _UTILITY_H_FILE_

#ifdef USE_XML_AND_FLTK

#include <FL/Fl.H>
#include <FL/Fl_Widget.H>
#include <tinyxml2.h>

#endif

class MessageLogger;
class MessageLoggerSingleton{
private:
protected:
	static MessageLogger* m_messageLogger;
	
public:
	MessageLoggerSingleton(MessageLogger& messageLogger);
	virtual ~MessageLoggerSingleton();
	
	static MessageLogger& GetLogger();
};

#define LOGGER (MessageLoggerSingleton::GetLogger())

char* IntToString(const int value, char* stringBuffer);
int StringToInt(const char* string);

template <class T> int Limit(const T value, const T down, const T up){
	return(value <down ?down :(value<up ?value :up));
}

#ifdef USE_XML_AND_FLTK

const char* LoadXmlAttribute(const tinyxml2::XMLElement& element, const char* field, const char* errorMessageHeader);

class Fl_Widget;
void Fl_MaximizeLabelFont(Fl_Widget& widget);

Fl_Color Fl_GetSelectedColor(Fl_Color color);

int GetScreenWidth();

#endif

#endif
